@@ -3,8 +3,11 @@
 
 from . import Utils
 
-from .GlobalConfig import GlobalConfig, InputEndian
-from .Context import Context, SymbolSpecialType, ContextSymbolBase, ContextSymbol, ContextOffsetSymbol, ContextRelocSymbol
+from .SortedDict import SortedDict
+from .GlobalConfig import GlobalConfig, InputEndian, Compiler
 from .FileSectionType import FileSectionType, FileSections_ListBasic, FileSections_ListAll
+from .ContextSymbols import SymbolSpecialType, ContextSymbol, ContextOffsetSymbol, ContextRelocSymbol
+from .SymbolsSegment import SymbolsSegment
+from .Context import Context
 from .FileSplitFormat import FileSplitFormat, FileSplitEntry
 from .ElementBase import ElementBase
