@@ -13,17 +13,14 @@ from . import SectionBase
 
 
 class SectionRodata(SectionBase):
-    def __init__(self, context: common.Context, vram: int|None, filename: str, array_of_bytes: bytearray):
-        super().__init__(context, vram, filename, array_of_bytes, common.FileSectionType.Rodata)
+    def __init__(self, context: common.Context, vromStart: int, vromEnd: int, vram: int, filename: str, array_of_bytes: bytearray, segmentVromStart: int, overlayCategory: str|None):
+        super().__init__(context, vromStart, vromEnd, vram, filename, array_of_bytes, common.FileSectionType.Rodata, segmentVromStart, overlayCategory)
 
         self.bytes: bytearray = bytearray(self.sizew*4)
         common.Utils.beWordsToBytes(self.words, self.bytes)
 
-        # addresses of symbols in this rodata section
-        self.symbolsVRams: set[int] = set()
 
-
-    def _stringGuesser(self, contextSym: common.ContextSymbolBase, localOffset: int) -> bool:
+    def _stringGuesser(self, contextSym: common.ContextSymbol, localOffset: int) -> bool:
         if contextSym.isMaybeString or contextSym.isString():
             return True
 
@@ -53,7 +50,7 @@ class SectionRodata(SectionBase):
         for w in self.words:
             relocSymbol = self.context.getRelocSymbol(inFileOffset, self.sectionType)
             if relocSymbol is not None:
-                if relocSymbol.name.startswith("."):
+                if relocSymbol.name is not None and relocSymbol.name.startswith("."):
                     sectType = common.FileSectionType.fromStr(relocSymbol.name)
                     relocSymbol.sectionType = sectType
 
@@ -81,7 +78,7 @@ class SectionRodata(SectionBase):
         partOfJumpTable = False
         for w in self.words:
             currentVram = self.getVramOffset(localOffset)
-            contextSym = self.context.getAnySymbol(currentVram)
+            contextSym = self.getSymbol(currentVram, tryPlusOffset=False)
 
             if contextSym is not None and contextSym.isJumpTable():
                 partOfJumpTable = True
@@ -90,54 +87,68 @@ class SectionRodata(SectionBase):
                 if localOffset in self.pointersOffsets:
                     partOfJumpTable = True
 
-                elif self.context.getGenericSymbol(currentVram) is not None:
+                elif contextSym is not None:
                     partOfJumpTable = False
 
                 elif ((w >> 24) & 0xFF) != 0x80:
                     partOfJumpTable = False
 
             if partOfJumpTable:
-                labelSym = self.context.addJumpTableLabel(w, isAutogenerated=True)
+                labelSym = self.addJumpTableLabel(w, isAutogenerated=True)
                 labelSym.referenceCounter += 1
 
-            elif currentVram in self.context.newPointersInData:
+            elif self.popPointerInDataReference(currentVram) is not None:
                 if common.GlobalConfig.ADD_NEW_SYMBOLS:
-                    contextSym = self.context.getAnySymbol(currentVram)
-                    if contextSym is None:
-                        contextSym = self.context.addSymbol(currentVram, None, self.sectionType, isAutogenerated=True)
-                        contextSym.isDefined = True
-
+                    contextSym = self.addSymbol(currentVram, self.sectionType, isAutogenerated=True)
                     contextSym.isMaybeString = self._stringGuesser(contextSym, localOffset)
-                    self.context.newPointersInData.remove(currentVram)
 
             elif contextSym is not None:
                 contextSym.isMaybeString = self._stringGuesser(contextSym, localOffset)
 
-            contextSym = self.context.getAnySymbol(currentVram)
+            contextSym = self.getSymbol(currentVram, tryPlusOffset=False)
             if contextSym is not None:
                 self.symbolsVRams.add(currentVram)
-                contextSym.isDefined = True
 
-                symbolList.append((localOffset, currentVram, contextSym.name))
+                symbolList.append((localOffset, currentVram))
 
             localOffset += 4
 
-        for i, (offset, vram, symName) in enumerate(symbolList):
+        previousSymbolWasLateRodata = False
+        previousSymbolExtraPadding = 0
+
+        for i, (offset, vram) in enumerate(symbolList):
             if i + 1 == len(symbolList):
                 words = self.words[offset//4:]
             else:
                 nextOffset = symbolList[i+1][0]
                 words = self.words[offset//4:nextOffset//4]
 
-            symVram = None
-            if self.vram is not None:
-                symVram = vram
-
-            sym = symbols.SymbolRodata(self.context, offset + self.inFileOffset, symVram, symName, words)
+            vrom = self.getVromOffset(offset)
+            vromEnd = vrom + len(words)*4
+            sym = symbols.SymbolRodata(self.context, vrom, vromEnd, offset + self.inFileOffset, vram, words, self.segmentVromStart, self.overlayCategory)
+            sym.parent = self
             sym.setCommentOffset(self.commentOffset)
             sym.analyze()
             self.symbolList.append(sym)
 
+            # File boundaries detection
+            if sym.inFileOffset % 16 == 0:
+                # Files are always 0x10 aligned
+
+                if previousSymbolWasLateRodata and not sym.contextSym.isLateRodata():
+                    # late rodata followed by normal rodata implies a file split
+                    self.fileBoundaries.append(sym.inFileOffset)
+                elif previousSymbolExtraPadding > 0:
+                    if sym.contextSym.isDouble():
+                        # doubles require a bit extra of alignment
+                        if previousSymbolExtraPadding >= 2:
+                            self.fileBoundaries.append(sym.inFileOffset)
+                    else:
+                        self.fileBoundaries.append(sym.inFileOffset)
+
+            previousSymbolWasLateRodata = sym.contextSym.isLateRodata()
+            previousSymbolExtraPadding = sym.countExtraPadding()
+
         self._processElfRelocSymbols()
 
 
